yakumo.nova.v2.floating_ip_bulk.Manager

Package yakumo :: Package nova :: Package v2 :: Module floating_ip_bulk :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for floating IP bulks in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for floating IP bulks in Compute API v2

Instance Methods | [hide private]
find_gen(self, host=None) Bulk-get floating IPs | source code
None |
create(self, pool=`'``__UNDEF__``'`, ip_range=`'``__UNDEF__``'`, interface=`'``__UNDEF__``'`) Bulk-create floating IPs | source code
None |
delete(self, ip_range=None) Bulk-create floating IPs | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``ip``'``,` `'``address``'``,` <yakumo.mapper.NoopClass ob`...``
| _hidden_methods = ``[``'``update``'``]``
| _id_attr = ``'``ip``'``
| _json_resource_key = ``'``floating_ip_info``'``
| _json_resources_key = ``'``floating_ip_info``'``
| _url_resource_path = ``'``/os-floating-ips-bulk``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### find_gen(self, host=None) | source code
Bulk-get floating IPs :param host=: hostname (str)

### create(self, pool=`'``__UNDEF__``'`, ip_range=`'``__UNDEF__``'`, interface=`'``__UNDEF__``'`) | source code
Bulk-create floating IPs Parameters: `pool` (Pool name (str, required)) - Pool name (str, required) `ip_range` (CIDR like '192.168.1.0/24' (str, required)) - CIDR like '192.168.1.0/24' (str, required) `interface` (Interface name like 'eth0' (str)) - Interface name like 'eth0' (str) Returns: None Resource object (empty) Overrides: base.Manager.create

### delete(self, ip_range=None) | source code
Bulk-create floating IPs Parameters: `ip_range` (str) - CIDR like '192.168.1.0/24' (required) Returns: None

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('ip', 'address', mapper.Noop), ('ip_range', 'ip_range', mapper.Noop)
      , ('server', 'instance_uuid', mapper.Resource('nova.server')), ('inter
      face', 'interface', mapper.Noop), ('project', 'project_id', mapper.Res
      ource('project')),]